<?php
/**
* @author      Opensource Design, http://www.opensourcedesign.nl
* @copyright   Copyright (C) 2009 Opensource Design. All rights reserved.
* @license     GNU General Public License, http://www.gnu.org/copyleft/gpl.html
* @Version     3.0.0
*
* The plugin f2csubmitmailer is a Form2Content adaption of the jp_submitmailer
* developed by Tobias Kuhn @ JoomlaPraise, http://www.joomlapraise.com
**/

// no direct access
defined('_JEXEC') or die;

jimport('joomla.plugin.plugin');

class plgSystemF2cSubmitMailer extends JPlugin
{
	function onAfterInitialise()
	{
		// ensure that the plug-in gets triggered only once
		if(!defined('F2C_SUBMITMAILER')) 
		{
			define('F2C_SUBMITMAILER', 1);
		}
		else 
		{
			return true;
		}

		$app  	= JFactory::getApplication();
		$db 	= JFactory::getDBO();
		$user   = JFactory::getUser();
		$acl	= JFactory::getACL();

		// Check if this is a front-end Form2Content operation
		if (!($app->getName() == 'site' && $app->input->get('option') == 'com_form2content' && 
			in_array($app->input->getCmd('task'), array('form.save', 'form.apply'))))
		{
			// Not a Form2Content operation
			return true;
		}

		$contentTypeId 	= (int)$_POST['jform']['projectid'];
		
		// Determine the id of the form we're editing
		$idList 	= $app->getUserState('com_form2content.edit.form.id');
		$f2cId 		= 0;
		
		if(count($idList))
		{
			$f2cId = $idList[0];
		}
			
		// Return if the user has updated a F2C article and we don't want to know about it
		if(!(int)$this->params->get('notify_on_update') && !$app->getUserState('com_form2content.edit.form.new'))
		{
			return true;
		}

		// Get the Content Type
		$query = $db->getQuery(true);
		$query->select('*');
		$query->from('#__f2c_project');
		$query->where('id = ' . $contentTypeId);
		
		$db->setQuery($query);
		
		$contentType = $db->loadObject();

		$contentTypeSettings = new JRegistry();
		$contentTypeSettings->loadString($contentType->settings);

		// Check if Content Type filter has been set
		if($this->params->get('filter_contenttype', 0) != 0)
		{
			if(!in_array($contentType->id, $this->params->get('contenttype_selection', array())))
			{
				// Content Type excluded for notification
				return true;
			}
		}
		
		if($app->getUserState('com_form2content.edit.form.new')) 
		{     		
			// User has created a new item
			$subject  = $this->params->get('new_subject');
			$body = $this->params->get('new_body');
		}
		else 
		{  
			// User is updating an existing item
			$subject  = $this->params->get('update_subject');
			$body = $this->params->get('update_body');
		}

		// Get the category for the form
		if(array_key_exists('jform', $_POST) && array_key_exists('catid', $_POST['jform']))
		{
			// Get the category from the request
			$catId = (int)$_POST['jform']['catid'];
		}
		else
		{
			if(!$app->getUserState('com_form2content.edit.form.new'))
			{
				// get the category from the existing article
				$query = $db->getQuery(true);
				$query->select('catid');
				$query->from('#__f2c_form');
				$query->where('id = ' . (int)$f2cId);
				
				$db->setQuery($query);
				
				$catId = $db->loadResult();
			}
			else
			{
				// get the default from the Content Type
				$catId = $contentTypeSettings->get('catid');
			}
		}
		
		// Get the title for the form
		if(array_key_exists('jform', $_POST) && array_key_exists('title', $_POST['jform']))
		{
			// Get the title from the request
			$title= $_POST['jform']['title'];
		}
		else
		{
			if($f2cId)
			{
				// get the title from the existing article
				$query = $db->getQuery(true);
				$query->select('title');
				$query->from('#__f2c_form');
				$query->where('id = ' . (int)$f2cId);
				
				$db->setQuery($query);
				
				$title = $db->loadResult();
			}
			else
			{
				// get the default from the Content Type
				$title = $contentTypeSettings->get('title_default');
			}
		}
		
		// Get the name for the category
		$query = $db->getQuery(true);
		$query->select('title');
		$query->from('#__categories');
		$query->where('id = ' . (int)$catId);

		$db->setQuery($query);
				
		$category = $db->loadResult();

		if(!$category)
		{
			$category = JText::_('PLG_F2CSUBMITMAILER_UNCATEGORIZED');
		}
	
		$query = $db->getQuery(true);
		$query->select('reference_id');
		$query->from('#__f2c_form');
		$query->where('id = ' . (int)$f2cId);
		
		$db->setQuery($query);
		
		$joomlaId = $db->loadResult();
				
		$username 	= ($user->get('username')) ? $user->get('username') : JText::_('PLG_F2CSUBMITMAILER_ANONYMOUS');
	
		$subject = str_replace('{url}', JURI::base(), $subject);
		$subject = str_replace('{username}', $username, $subject);
		$subject = str_replace('{category}', $category, $subject);
		$subject = str_replace('{contentType}', $contentType->title, $subject);
		$subject = str_replace('{title}', $title, $subject);
		$subject = str_replace('{joomlaId}', $joomlaId, $subject);
		
		// Prepare e-mail body
		$body = str_replace('{url}', JURI::base(), $body);
		$body = str_replace('{username}', $username, $body);
		$body = str_replace('{category}', $category, $body);
		$body = str_replace('{contentType}', $contentType->title, $body);
		$body = str_replace('{title}', $title, $body);
		$body = str_replace('{id}', $f2cId, $body);
		$body = str_replace('{joomlaId}', $joomlaId, $body);
		
		$emails = array();	
		$sent 	= array();
				
		// send email to group users
		if((int)$this->params->get('mail_to_groups') && (int)$this->params->get('mail_groups')) 
		{			
			// get users in the group out of the acl
			$to = $acl->getUsersByGroup((int)$this->params->get('mail_groups'), (int)$this->params->get('recurse_groups'));
	
			// Get all users email
			$query	= $db->getQuery(true);
			$query->select('email');
			$query->from('#__users');
	
			if (empty($to)) 
			{
				$query->where('0');
			} 
			else 
			{
				$query->where('id IN (' . implode(',', $to) . ')');
			}
	
			$db->setQuery($query);
			$tmp_emails = $db->loadColumn();

			if(!is_array($emails)) 
			{ 
				$emails = array();
			}
			
			$emails = array_merge($tmp_emails, $emails);
		}
	
		// send email to custom addresses
		if((int)$this->params->get('mailto_custom') && $this->params->get('custom_email') != "")  
		{
			$tmp_emails = explode(';', $this->params->get('custom_email'));
	
			if(!is_array($emails)) 
			{
				$emails = array();
			}
			
			$emails = array_merge($tmp_emails, $emails);
		}

		// send email
		foreach ($emails as $email)
		{
			// don't send doubles
			if(!in_array($email, $sent)) 
			{
				$email = trim($email);
	
				$mail = JFactory::getMailer();
	
				$mail->addRecipient($email);
				$mail->setSender(array($app->getCfg('mailfrom'), $app->getCfg('fromname')));
				$mail->setSubject($subject);
				$mail->setBody($body);
				$mail->Send();
				$sent[] = $email;
			}
		}

		return true;
	}
}
